@@ -1,18 +1,18 @@
 #![feature(try_blocks)]
 
-use dll_syringe::Process;
-use dll_syringe::Syringe;
-use std::path::Path;
+use dll_syringe::{Process, Syringe};
 use std::{
     error::Error,
+    path::Path,
     process::{Command, Stdio},
 };
 
+#[allow(unused)]
 mod common;
 
 #[test]
 #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
-fn eject_32_from_32() -> Result<(), Box<dyn Error>> {
+fn eject_32() -> Result<(), Box<dyn Error>> {
     eject_test(
         common::build_test_payload_x86()?,
         common::build_test_target_x86()?,
@@ -21,7 +21,7 @@ fn eject_32_from_32() -> Result<(), Box<dyn Error>> {
 
 #[test]
 #[cfg(target_arch = "x86_64")]
-fn eject_64_from_64() -> Result<(), Box<dyn Error>> {
+fn eject_64() -> Result<(), Box<dyn Error>> {
     eject_test(
         common::build_test_payload_x64()?,
         common::build_test_target_x64()?,
@@ -41,7 +41,7 @@ fn eject_test(
 
     let syringe = Syringe::new();
     let module = syringe.inject(&dummy_process, payload_path.as_ref())?;
-    module.eject()?;
+    syringe.eject(module)?;
 
     dummy_process.kill()?;
 
