@@ -1,18 +1,18 @@
 #![feature(try_blocks)]
 
-use dll_syringe::Process;
-use dll_syringe::Syringe;
-use std::path::Path;
+use dll_syringe::{Process, Syringe};
 use std::{
     error::Error,
+    path::Path,
     process::{Command, Stdio},
 };
 
+#[allow(unused)]
 mod common;
 
 #[test]
 #[cfg(any(target_arch = "x86", target_arch = "x86_64"))]
-fn inject_32_from_32() -> Result<(), Box<dyn Error>> {
+fn inject_32() -> Result<(), Box<dyn Error>> {
     inject_test(
         common::build_test_payload_x86()?,
         common::build_test_target_x86()?,
@@ -21,7 +21,7 @@ fn inject_32_from_32() -> Result<(), Box<dyn Error>> {
 
 #[test]
 #[cfg(target_arch = "x86_64")]
-fn inject_64_from_64() -> Result<(), Box<dyn Error>> {
+fn inject_64() -> Result<(), Box<dyn Error>> {
     inject_test(
         common::build_test_payload_x64()?,
         common::build_test_target_x64()?,
